<div align="center">
    <img src="https://cdn0.iconfinder.com/data/icons/smart-farm-line-agriculture-technology/512/Irrigation-512.png" alt="logo" height="128">
</div>

# ezapi-icc-pro

[![pytest](https://github.com/zehengl/ezapi-icc-pro/actions/workflows/pytest.yml/badge.svg)](https://github.com/zehengl/ezapi-icc-pro/actions/workflows/pytest.yml)
![coding_style](https://img.shields.io/badge/code%20style-black-000000.svg)
![PyPI - License](https://img.shields.io/pypi/l/ezapi-icc-pro)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/ezapi-icc-pro)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/ezapi-icc-pro)
[![Downloads](https://static.pepy.tech/badge/ezapi-icc-pro)](https://pepy.tech/project/ezapi-icc-pro)
[![GitHub Pages](https://github.com/zehengl/ezapi-icc-pro/actions/workflows/gh-deploy.yml/badge.svg)](https://github.com/zehengl/ezapi-icc-pro/actions/workflows/gh-deploy.yml)

A Python wrapper for ICC PRO RESTful API

## Install

From [PyPi](https://pypi.org/project/ezapi-icc-pro/)

    pip install ezapi-icc-pro

From [GitHub](https://github.com/zehengl/ezapi-icc-pro)

    pip install git+https://github.com/zehengl/ezapi-icc-pro.git

## Usage

Check out these [examples](https://zehengl.github.io/ezapi-icc-pro/endpoints/).

## Credits

- [Logo][1] by [Chanut is Industries][2]

[1]: https://www.iconfinder.com/icons/4629153/agricultural_agriculture_agritect_farming_irrigation_smart_farm_water_icon
[2]: https://www.iconfinder.com/Chanut-is
